==> 0.109.x.zip: opentelemetry-collector-contrib/exporter/pulsarexporter/factory_test.go <==
// Copyright The OpenTelemetry Authors
// SPDX-License-Identifier: Apache-2.0

package pulsarexporter

import (
	"context"
	"testing"
	"time"

	"github.com/stretchr/testify/assert"
	"github.com/stretchr/testify/require"
	"go.opentelemetry.io/collector/component/componenttest"
	"go.opentelemetry.io/collector/config/configretry"
	"go.opentelemetry.io/collector/exporter/exporterhelper"
	"go.opentelemetry.io/collector/exporter/exportertest"
)

func Test_createDefaultConfig(t *testing.T) {
	cfg := createDefaultConfig()
	assert.Equal(t, &Config{
		TimeoutSettings: exporterhelper.NewDefaultTimeoutSettings(),
		BackOffConfig:   configretry.NewDefaultBackOffConfig(),
		QueueSettings:   exporterhelper.NewDefaultQueueSettings(),
		Endpoint:        defaultBroker,

		Topic:                   "",
		Encoding:                defaultEncoding,
		Authentication:          Authentication{},
		MaxConnectionsPerBroker: 1,
		ConnectionTimeout:       5 * time.Second,
		OperationTimeout:        30 * time.Second,
	}, cfg)
}

func TestWithTracesMarshalers_err(t *testing.T) {
	cfg := createDefaultConfig().(*Config)
	cfg.Endpoint = ""

	tracesMarshaler := &customTraceMarshaler{encoding: "unknown"}
	f := NewFactory(withTracesMarshalers(tracesMarshaler))
	r, err := f.CreateTracesExporter(context.Background(), exportertest.NewNopSettings(), cfg)
	require.NoError(t, err)
	err = r.Start(context.Background(), componenttest.NewNopHost())
	// no available broker
	require.Error(t, err)
}

func TestCreateTracesExporter_err(t *testing.T) {
	cfg := createDefaultConfig().(*Config)
	cfg.Endpoint = ""

	f := pulsarExporterFactory{tracesMarshalers: tracesMarshalers()}
	r, err := f.createTracesExporter(context.Background(), exportertest.NewNopSettings(), cfg)
	require.NoError(t, err)
	err = r.Start(context.Background(), componenttest.NewNopHost())
	// no available broker
	require.Error(t, err)
}

func TestCreateMetricsExporter_err(t *testing.T) {
	cfg := createDefaultConfig().(*Config)
	cfg.Endpoint = ""

	mf := pulsarExporterFactory{metricsMarshalers: metricsMarshalers()}
	r, err := mf.createMetricsExporter(context.Background(), exportertest.NewNopSettings(), cfg)
	require.NoError(t, err)
	err = r.Start(context.Background(), componenttest.NewNopHost())
	require.Error(t, err)
}

func TestCreateLogsExporter_err(t *testing.T) {
	cfg := createDefaultConfig().(*Config)
	cfg.Endpoint = ""

	mf := pulsarExporterFactory{logsMarshalers: logsMarshalers()}
	r, err := mf.createLogsExporter(context.Background(), exportertest.NewNopSettings(), cfg)
	require.NoError(t, err)
	err = r.Start(context.Background(), componenttest.NewNopHost())
	require.Error(t, err)
}

==> 0.119.x.zip: opentelemetry-collector-contrib/exporter/pulsarexporter/factory_test.go <==
// Copyright The OpenTelemetry Authors
// SPDX-License-Identifier: Apache-2.0

package pulsarexporter

import (
	"context"
	"testing"
	"time"

	"github.com/stretchr/testify/assert"
	"github.com/stretchr/testify/require"
	"go.opentelemetry.io/collector/component/componenttest"
	"go.opentelemetry.io/collector/config/configretry"
	"go.opentelemetry.io/collector/exporter/exporterhelper"
	"go.opentelemetry.io/collector/exporter/exportertest"
)

func Test_createDefaultConfig(t *testing.T) {
	cfg := createDefaultConfig()
	assert.Equal(t, &Config{
		TimeoutSettings: exporterhelper.NewDefaultTimeoutConfig(),
		BackOffConfig:   configretry.NewDefaultBackOffConfig(),
		QueueSettings:   exporterhelper.NewDefaultQueueConfig(),
		Endpoint:        defaultBroker,

		Topic:                   "",
		Encoding:                defaultEncoding,
		Authentication:          Authentication{},
		MaxConnectionsPerBroker: 1,
		ConnectionTimeout:       5 * time.Second,
		OperationTimeout:        30 * time.Second,
	}, cfg)
}

func TestWithTracesMarshalers_err(t *testing.T) {
	cfg := createDefaultConfig().(*Config)
	cfg.Endpoint = ""

	tracesMarshaler := &customTraceMarshaler{encoding: "unknown"}
	f := NewFactory(withTracesMarshalers(tracesMarshaler))
	r, err := f.CreateTraces(context.Background(), exportertest.NewNopSettings(), cfg)
	require.NoError(t, err)
	err = r.Start(context.Background(), componenttest.NewNopHost())
	// no available broker
	require.Error(t, err)
}

func TestCreateTraces_err(t *testing.T) {
	cfg := createDefaultConfig().(*Config)
	cfg.Endpoint = ""

	f := pulsarExporterFactory{tracesMarshalers: tracesMarshalers()}
	r, err := f.createTracesExporter(context.Background(), exportertest.NewNopSettings(), cfg)
	require.NoError(t, err)
	err = r.Start(context.Background(), componenttest.NewNopHost())
	// no available broker
	require.Error(t, err)
}

func TestCreateMetrics_err(t *testing.T) {
	cfg := createDefaultConfig().(*Config)
	cfg.Endpoint = ""

	mf := pulsarExporterFactory{metricsMarshalers: metricsMarshalers()}
	r, err := mf.createMetricsExporter(context.Background(), exportertest.NewNopSettings(), cfg)
	require.NoError(t, err)
	err = r.Start(context.Background(), componenttest.NewNopHost())
	require.Error(t, err)
}

func TestCreateLogs_err(t *testing.T) {
	cfg := createDefaultConfig().(*Config)
	cfg.Endpoint = ""

	mf := pulsarExporterFactory{logsMarshalers: logsMarshalers()}
	r, err := mf.createLogsExporter(context.Background(), exportertest.NewNopSettings(), cfg)
	require.NoError(t, err)
	err = r.Start(context.Background(), componenttest.NewNopHost())
	require.Error(t, err)
}
